/*********************************
 * This file is part of the "Interactive Fan Chart Demo"
 * by Geoffrey M. Draper.
 * 
 * Geoffrey M. Draper, author of this work, hereby grants
 * everyone permission to use and distribute this code,
 * with or without modifications for any purpose,
 * commercial or otherwise. 
 * 
 * It is requested, although not required, that derivative
 * works include an acknowledgment somewhere in the
 * derivative work's credits.
 *********************************/

package fanchart;

import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;


//Refactored out of the Main and MainApplet classes
//for simplicity in maintenance.
public class MyMenuBar extends JMenuBar {
	private ActionListener listener;
	
	public static final String ABOUT_MENU_OPTION = "About...";
	public static final String EXIT_MENU_OPTION = "Exit";
	public static final String SET_NUM_GENERATIONS_OPTION = "Set number of generations to display...";
	public static final String TOGGLE_ANIMATION_OPTION = "Toggle animation";
	public static final String SELECT_ARBITRARY_ROOT = "Select New Root Person...";
	public static final String TOGGLE_CLICK_TO_EXPAND = "Clicking a node expands it.";
	
	public MyMenuBar(ActionListener al) {
		super();
		listener = al;
		build();
	}
	
	private void build() {
		//create File menu
		JMenu fileMenu = new JMenu("File");
		JMenuItem menuItem;
		menuItem = new JMenuItem(EXIT_MENU_OPTION, KeyEvent.VK_X);
		menuItem.setActionCommand(EXIT_MENU_OPTION);
		menuItem.addActionListener(listener);
		fileMenu.add(menuItem);

		//create Config menu
		JMenu configMenu = new JMenu("Options");
		menuItem = new JMenuItem(SET_NUM_GENERATIONS_OPTION);
		menuItem.setActionCommand(SET_NUM_GENERATIONS_OPTION);
		menuItem.addActionListener(listener);
		configMenu.add(menuItem);
		menuItem = new JCheckBoxMenuItem(TOGGLE_ANIMATION_OPTION, Config.db_animate);
		menuItem.setActionCommand(TOGGLE_ANIMATION_OPTION);
		menuItem.addActionListener(listener);
		configMenu.add(menuItem);
		menuItem = new JCheckBoxMenuItem(TOGGLE_CLICK_TO_EXPAND, Config.clickToExpand);
		menuItem.setActionCommand(TOGGLE_CLICK_TO_EXPAND);
		menuItem.addActionListener(listener);
		configMenu.add(menuItem);
		
		//create People menu
		JMenu peopleMenu = new JMenu("People");
		menuItem = new JMenuItem(SELECT_ARBITRARY_ROOT);
		menuItem.setActionCommand(SELECT_ARBITRARY_ROOT);
		menuItem.addActionListener(listener);
		peopleMenu.add(menuItem);
		
		//create Help menu
		JMenu helpMenu = new JMenu("Help");
		helpMenu.setMnemonic(KeyEvent.VK_H);
		menuItem = new JMenuItem(ABOUT_MENU_OPTION);
		menuItem.setActionCommand(ABOUT_MENU_OPTION);
		menuItem.addActionListener(listener);
		helpMenu.add(menuItem);

		add(fileMenu);
		add(peopleMenu);
		add(configMenu);
		add(helpMenu);

	}
	
}
