/*********************************
 * This file is part of the "Interactive Fan Chart Demo"
 * by Geoffrey M. Draper.
 * 
 * Geoffrey M. Draper, author of this work, hereby grants
 * everyone permission to use and distribute this code,
 * with or without modifications for any purpose,
 * commercial or otherwise. 
 * 
 * It is requested, although not required, that derivative
 * works include an acknowledgment somewhere in the
 * derivative work's credits.
 *********************************/

package fanchart;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.BoxLayout;
import javax.swing.DefaultListModel;
import javax.swing.JApplet;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ListCellRenderer;
import javax.swing.ListSelectionModel;

public class PersonSelectorDialog extends JDialog implements ActionListener {
	private JList familyListBox;
	private DefaultListModel listModel;
	private Ward ward;
	private static final long serialVersionUID = 42L;
	
	private static final String OK = "OK";
	private static final String CANCEL = "Cancel";
	
	public PersonSelectorDialog(Frame parent, Ward ward) {
		super(parent, "Select New Root Person");
		init(parent, ward);
	}
	
	public PersonSelectorDialog(JApplet parent, Ward ward) {
		super();
		setTitle("Select New Root Person");
		init(parent, ward);
	}
	
	private void init(Component parent, Ward ward) {
		this.ward = ward;
		buildGUI();
		setResizable(false);
		pack();
		
		//position this dialog in the middle of its parent window
		Rectangle parentBounds = parent.getBounds();
		Dimension mySize = getSize();
		setLocation(parentBounds.x + parentBounds.width/2 - mySize.width/2,
				parentBounds.y + parentBounds.height/2 - mySize.height/2);

		setVisible(true);		
	}
		
	private void buildGUI() {
		setLayout(new BoxLayout(getContentPane(), BoxLayout.PAGE_AXIS));
		add(new JLabel("Please select a new root person."));
		listModel = new DefaultListModel();
		familyListBox = new JList(listModel);
		familyListBox.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		familyListBox.setCellRenderer(new MyCellRenderer());
		MouseListener mouseListener = new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				if (e.getClickCount() == 2) {
					handleActionEvent(OK);
				}
			}
		};
		familyListBox.addMouseListener(mouseListener);
		JScrollPane listScroller = new JScrollPane(familyListBox);
		add(listScroller);
		
		add(createButtonPanel());
		refresh();
	}
	
	private JPanel createButtonPanel() {
		JPanel buttonPane = new JPanel();
		buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.PAGE_AXIS));
		JPanel row2 = new JPanel();
		final JButton okButton = new JButton(OK);
		okButton.setActionCommand(OK);
		okButton.addActionListener(this);
		row2.add(okButton);
		final JButton cancelButton = new JButton(CANCEL);
		cancelButton.setActionCommand(CANCEL);
		cancelButton.addActionListener(this);
		row2.add(cancelButton);
		buttonPane.add(row2);
		return buttonPane;
	}
	
	private void refresh() {
		listModel.clear();
		for (Person f : ward.getLinearList()) {
			listModel.addElement(f);
		}
	}
	
	public void actionPerformed(ActionEvent e) {
		String command = e.getActionCommand();
		handleActionEvent(command);
	}
	
	private void handleActionEvent(String command) {
		if (command.equals(OK)) {
			Person p = (Person)familyListBox.getSelectedValue();
			if (p != null) {
				ward.setRootPerson(p);
				ward.assignmentsChanged();
			}
		}
		setVisible(false);
	}
	
	private class MyCellRenderer extends JLabel implements ListCellRenderer {

		private static final long serialVersionUID = 42L;

		public Component getListCellRendererComponent(
				JList list,
				Object value,            // value to display
				int index,               // cell index
				boolean isSelected,      // is the cell selected
				boolean cellHasFocus)    // the list and the cell have the focus
		{
			String s = "";
			if (value instanceof Person) {
				s = ((Person)value).getName();
			}
			setText(s);
			if (isSelected) {
				setBackground(list.getSelectionBackground());
				setForeground(list.getSelectionForeground());
			}
			else {
				setBackground(list.getBackground());
				setForeground(list.getForeground());
			}
			setEnabled(list.isEnabled());
			setFont(list.getFont());
			setOpaque(true);
			return this;
		}
	}

}
